@@ -8,6 +8,7 @@ class AssetsTest < ActiveSupport::TestCase
     require "sprockets/railtie"
 
     @app = Class.new(Rails::Application)
+    @app.config.eager_load = false
     @app.config.active_support.deprecation = :stderr
     @app.config.assets.enabled = true
     @app.config.assets.cache_store = [ :file_store, "#{tmp_path}/cache" ]
@@ -25,7 +26,7 @@ class AssetsTest < ActiveSupport::TestCase
     @app.assets["coffee-script"].write_to("#{tmp_path}/coffee-script.js")
 
     assert_match "/lib/assets/javascripts/coffee-script.js.erb", @app.assets["coffee-script"].pathname.to_s
-    assert_match "this.CoffeeScript", File.open("#{tmp_path}/coffee-script.js").read
+    assert_match "CoffeeScript Compiler", File.open("#{tmp_path}/coffee-script.js").read
   end
 
   def tmp_path
