@@ -12,7 +12,7 @@ class ControllerGeneratorTest < Rails::Generators::TestCase
   end
 
   def test_assets
-    run_generator %w(posts --javascript-engine=coffee --orm=false)
+    run_generator %w(posts --javascripts --javascript-engine=coffee --orm=false)
     assert_no_file "app/assets/javascripts/posts.js"
     assert_file "app/assets/javascripts/posts.coffee"
   end
